
llstatus - Query machine status

Use the llstatus command to return status information about machines in
the LoadLeveler cluster.

Syntax
 
llstatus [-?] [-H] [-v] [-W] [-R] [-F] [-M] [-l] [-a] [-C] [-b]
         [-B {base_partition_list | all}] [-P {partition_list | all}]
         [-X {cluster_list | all}] [-f category_list] [-r category_list]
         [-h hostlist | hostlist]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-R 
   Lists the machine consumable resources associated with each machine
   for which status is requested. Only -h hostlist or hostlist can be
   specified with the -R flag.

-F 
   Lists all of the floating consumable resources associated with the
   LoadLeveler cluster. This option should not be used with any other
   option.

-M 
   Lists the Multiple Chip Modules (MCMs) available on a machine, where:
   
   Available CPUs
            Are the CPU IDs of the CPUs available for LoadLeveler on
            this MCM.
   Used CPUs
            Are the CPU IDs of the CPUs used by LoadLeveler jobs on this
            MCM.
   Adapters Are the switch adapters connected to this MCM of the form: 
            [available windows, available rCxtBlocks]
             
            where:
             
            available windows
                     Is the total number of windows on the adapter.
            available rCxt blocks
                     Is the total number of rCxt blocks on the adapter.
   Total Tasks
            Is the total number of tasks that are running using CPUs of
            this MCM.
    
   Note that the < > notation will be used to list individual CPU IDs
   instead of the CPU count ( ) notation when the RSET_SUPPORT
   configuration file keyword is set to RSET_MCM_AFFINITY.

-l 
   Specifies that a long listing be generated for each machine for which
   status is requested. If -l is not specified, the standard list is
   generated.

-a 
   Displays information for each virtual adapter followed by information
   for each physical adapter it manages. This flag also displays the
   port number on each InfiniBand adapter port.

-C 
   Displays cluster stanza information defined in the administration
   file. Only fields that contain data are displayed. If -C is specified
   without the -X flag, cluster stanza information will be reported from
   one outbound local Schedd. If the -X and -C flags are specified,
   cluster stanza information will be reported from an inbound Schedd in
   each available remote cluster specified with the -X flag. If the -h
   flag is specified, cluster stanza information will only be reported
   from the specified hosts.

-b 
   Displays Blue Gene system information. It is valid only when
   specified as a single option or in combination with the -l flag. When
   used as single option, llstatus displays a short listing of
   information on the Blue Gene system. When used the -l flag, llstatus
   displays a detailed listing of the components of the Blue Gene
   system.

-P {partition_list | all}
   Displays Blue Gene partition information. It is valid only when
   specified as a single option. When this flag is specified, llstatus
   displays information on all Blue Gene partitions in the
   partition_list. 

   partition_list
            Is a blank-delimited list of Blue Gene partitions.

   all      Is the reserved word indicating that the command is to
            return information for all partitions.

-B {base_partition_list | all}
   Displays Blue Gene base partition information. It is valid only when
   specified as a single option. When this flag is specified, llstatus
   displays information about all Blue Gene base partitions in the
   base_partition_list. 

   base_partition_list
            Is a blank-delimited list of Blue Gene base partitions.

   all      Is the reserved word indicating that the command is to
            return information for all base partitions.

-X {cluster_list | all}
   Indicates that you can specify the -X flag with either: 

   cluster_list
            Specifies a blank-delimited list of clusters for which
            status is requested.

   all      Is a reserved word which specifies that status is requested
            for all accessible clusters.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you
   to create a customized version of the standard llstatus listing. The
   output fields produced by this flag all have a fixed length. The
   output is displayed in the order in which you specify the categories.
   category_list can be one or more of the following: 

   %a       Hardware architecture

   %act     Number of job steps dispatched by the Schedd daemon on this
            machine

   %cm      Custom Metric value

   %cpu     Number of CPUs on this machine

   %d       Available disk space in the LoadLeveler execute directory

   %i       Number of seconds since last keyboard or mouse activity

   %inq     Number of job steps in the job queue of this Schedd machine

   %l       Berkeley one-minute load average

   %m       Physical memory on this machine

   %mt      Maximum number of initiators that can be used simultaneously
            on this machine

   %n       Machine name

   %o       Operating system on this machine

   %r       Number of initiators used by the startd daemon on this
            machine

   %sca     Availability of the Schedd daemon

   %scs     State of the Schedd daemon

   %sta     Availability of the startd daemon

   %sts     State of the startd daemon

   %v       Available swap space (free paging space) of this machine

   %X       Local cluster name

-r category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you
   to create a customized version of the standard llstatus listing. The
   output produced by this flag is considered raw, in that the fields
   can be variable in length. The output is displayed in the order in
   which you specify the formats. Output fields are separated by an
   exclamation point (!). category_list can be one or more of the
   categories listed under the -f flag.

-h hostlist
hostlist
   Is a blank-delimited list of machines for which status is requested. 

   If the -X flag is specified in combination with a hostlist, the -h
   flag must be specified. For example: 

   llstatus -X my_cluster1 my_cluster2 -h c94n13 c94n14

Description

If you have more than a few machines configured for LoadLeveler, 
consider redirecting the output to a file when using the -l flag. 
Each machine periodically updates the central manager with a 
snapshot of its situation on an interval calculated by 
POLLING_FREQUENCY * POLLS_PER_UPDATE. Since the information returned by 
using llstatus is a collection of such snapshots, all taken at varying 
times, the total picture may not be completely consistent.

In most cases, if a hostlist is not specified, all machines are queried.
However, if the -X and -C flags are specified without a hostlist, the
command will run on one inbound Schedd in the remote cluster. In this
case, the Schedd version information from the inbound Schedd in the
remote cluster will be displayed.

Certain resources such as remote direct-memory access (RDMA) have their
available value always calculated by startd. Available ConsumableCpus
resources are calculated by startd if the value is specified as all in
the administration file. When the value of a resource is calculated by
startd, the llstatus command appends a plus (+) sign to the resource
name in the output reports. Resources that are automatically created,
such as RDMA, have a less than (<) sign appended to them.

Examples

1. This example generates the standard listing where there are two nodes
   in the cluster. The standard listing is generated when you do not
   specify the -l option with the llstatus command. 

   llstatus 
    
   You should receive output similar to the following:
    
   Name                   Schedd InQ Act Startd Run LdAvg Idle Arch  OpSys
   k10n09.ppd.pok.ibm.com Avail   3   1  Run      1 2.72     0 R6000 AIX53
   k10n12.ppd.pok.ibm.com Avail   0   0  Idle     0 0.00   365 R6000 AIX53
   
   R6000/AIX53            2 machines   3 jobs   1 running tasks
   Total Machines         2 machines   3 jobs   1 running tasks
    
   The Central Manager is defined on k10n09.ppd.pok.ibm.com
   
   The BACKFILL scheduler is in use
   
   Cluster name is cluster2
   
   All machines on the machine_list are present. 
    
   The standard listing includes the following fields:
    
   Act      Number of job steps dispatched by the Schedd daemon on this
            machine.

   Arch     The hardware architecture of the machine as listed in the
            configuration file.

   Idle     The number of seconds since keyboard or mouse activity in a
            login session was detected. Highest number displayed is
            9999.

   InQ      Number of job steps in the job queue of this Schedd machine.

   LdAvg    Berkeley one-minute load average on this machine.

   Name     Host name of the machine.

   OpSys    The operating system on this machine.

   Run      The number of initiators used by the startd daemon to run
            LoadLeveler jobs on this machine. One initiator is used for
            each serial job step and one initiator is used for each task
            of a parallel job step.

   Schedd   State of the Schedd daemon, which can be one of the
            following: 
            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Avail (Available)
             
            For more information, see the description of the Schedd
            daemon in TWS LoadLeveler: Using and Administering.

   Startd   State of the startd daemon, which can be: 
            *  Busy
            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Flush
            *  Idle
            *  None
            *  Run (Running)
            *  Suspnd (Suspend)
             
            For more information, see the description of the startd
            daemon in TWS LoadLeveler: Using and Administering.

   Total Machines
            The standard listing includes the following summary fields: 

            jobs     The number of job steps in LoadLeveler job queues.

            machines The number of machines in the cluster that have
                     made a status report to the central manager.

            running tasks
                     The number of initiators used by all the startd
                     daemons in the LoadLeveler cluster. One initiator
                     is used for each serial job step. One initiator is
                     used for each task of a parallel job step.
    
   The standard listing also contains summary information for the
   cluster such as the type of scheduler and the cluster name.

2. This example generates the long listing. The long listing is
   generated when you specify the -l flag with the llstatus command. See
   the "Sample command output" topic for sample output of long listings
   in TWS LoadLeveler: Command and API Reference. 

   llstatus -l c271f2rp02
    
   The long listing includes the following fields:
    
   Adapter  Network adapter information associated with this machine. 

            *  For a switch adapter, the information format is: 

               adapter_name(network_type, interface_name, 
	       interface_address, multilink_address, switch_node_number 
	       or adapter_logical_id, available_adapter_windows/ 
	       total_adapter_windows, total rCxt blocks, 
	       adapter_fabric_connectivity,adapter_state)
                
               For example:
                
               Adapter = networks(striped,c60f1rp01ml0.ppd.pok.ibm.com, 
               10.10.10.1,,-1,32/32,1596/1596 rCxt Blks,1,READY) 
               en0(ethernet,c60f1rp01.ppd.pok.ibm.com,9.114.88.65,) 
               network1(aggregate,,,10.10.10.1,-1,32/32,1596/1596 
	          rCxt Blks,1, 
               READY)ml0(multilink,c60f1rp01ml0.ppd.pok.ibm.com,
	          10.10.10.1,)
                
               Possible values for adapter_state are:
                
               ErrAdapter 
                        The adapter information is incorrect. More
                        information might be available in the network
                        table API log.

               ErrDown  The adapter has been reported as down. This
                        field is displayed as part of the command output
                        when the adapter is found to be down by either
                        an adapter heartbeat, or by the input/output
                        control (ioctl) or protocol network services
                        daemon (PNSD) status on the machine.

               ErrInternal
                        An error occurred while accessing the adapter.
                        More information might be available in the
                        network table API log and if the D_FULLDEBUG and
                        D_ADAPTER flags are specified for STARTD_DEBUG.

               ErrNotConfigured
                        The adapter is not configured. This field is
                        displayed as part of the command output only
                        during start up and reconfiguration as a default
                        value until it is changed by either an ioctl or
                        PNSD, or an adapter heartbeat.

               ErrNTBL  An error occurred while accessing the network
                        table API. More information might be available
                        if the D_FULLDEBUG and D_ADAPTER flags are
                        specified for  STARTD_DEBUG.

               ErrPerm  The network table API reported that LoadLeveler
                        does not have permission to access the adapter.
                        More information might be available in the
                        network table API log.

               ErrPNSD  An error occurred in the network table API. More
                        information might be available in the network
                        table API log.

               ErrType  The network table API reported that the adapter
                        is not a switch adapter. Check the adapter
                        configuration.

               MachineDown
                        The machine to which the adapter is attached
                        could not be reached by LoadLeveler to query
                        status.

               NOT READY
                        An unspecified problem occurred when accessing
                        the adapter state. More information might be
                        available if the D_FULLDEBUG and D_ADAPTER flags
                        are specified for  STARTD_DEBUG.

               READY    The adapter can be used for communication.

            *  For non-switch adapters, the format is: 

               adapter_name(network_type, interface_name, 
	       interface_address, interface_netmask, multilink_address)
                
               Arch     Hardware architecture of this machine.

               AvailableClasses
                        List of available classes and the associated
                        number of available initiators on this machine.

               Completed
                        The number of job steps in this state on this
                        Schedd machine.

               Config Time Stamp
                        Date and time of last configuration or
                        reconfiguration.

               ConfiguredClasses
                        List of configured classes and the associated
                        number of configured initiators on this machine.

               ConsumableResources
                        List of consumable resources associated with
                        this machine. Each element of this list has the
                        format: resource_name(available, total). 

                        Note: The individual CPU ID < > notation will be
                              used to list individual CPU IDs instead of
                              the CPU count ( ) notation for machines 
			      where the RSET_SUPPORT configuration file 
			      keyword is set to RSET_MCM_AFFINITY. The 
			      CPU count ( ) notation will be used when 
			      the RSET_SUPPORT configuration file 
			      keyword is set to RSET_USER_DEFINED or 
			      RSET_NONE, or if this keyword is not 
			      specified in the configuration file.

               CONTINUE The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        suspended jobs are continued on this machine.

               Cpus     Number of CPUs on this machine.

               CustomMetric
                        This value can be the number assigned to the
                        CUSTOM_METRIC keyword or the exit code of the
                        executable associated with the
                        CUSTOM_METRIC_COMMAND keyword or the default
                        value of 1.

               Disk     Available space, in kilobytes (less 512 KB) in
                        LoadLeveler's execute directory on this machine.

               DrainedClasses
                        List of classes which have been drained. If a
                        job step is in a class named on this list, that
                        job step will not start on this machine.

               DrainingClasses
                        List of classes which are currently being
                        drained on this machine. If a job step is in a
                        class named on this list, that job step will not
                        start on this machine.

               Entered Current State
                        Date and time when machine state was set.

               FabricConnectivity
                        Represents the current state of connectivity
                        between the machine and the switch through the
                        switch adapters. The format of the field is:
                        network_id: connectivity, network_id:
                        connectivity... where connectivity is either 1
                        or 0. A value of 1 indicates an active
                        connection from the machine to a given
                        network_id through one of the switch adapters. 

                        If a machine does not have switch adapters, the
                        FabricConnectivity field has no meaning and
                        should be ignored by the user.

               Feature  Set of all features on this machine.

               FreeLargePageMemory
                        Free Large Page memory. 

                        In LoadLeveler for Linux, the
                        FreeLargePageMemory field has no meaning and
                        should be ignored by the user.

               FreeRealMemory
                        Free real memory, in megabytes, on this machine.
                        This value should track closely with the "fre"
                        value of the vmstat command and the "free" value
                        of the svmon -G command whose units are 4 KB
                        blocks.

               Held     The number of job steps in this state on this
                        Schedd machine.

               Idle     The number of job steps in this state on this
                        Schedd machine.

               Keyboard Idle
                        Number of seconds since last keyboard or mouse
                        activity.

               KILL     The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        jobs running on this machine should be sent the
                        SIGKILL signal.

               LargePageMemory
                        Configured Large Page physical memory. 

                        In LoadLeveler for Linux, the LargePageMemory
                        field has no meaning and should be ignored by
                        the user.

               LargePageSize
                        The size of a Large Page memory block. 

                        In LoadLeveler for Linux, the LargePageSize
                        field has no meaning and should be ignored by
                        the user.

               LoadAvg  Berkely one-minute load average on machine.

               Machine  Fully qualified name of the machine.

               Machine Mode
                        The type of job this machine can run. This can
                        be: batch, interactive, or general.

               MACHPRIO Actual expression that determines machine
                        priority, defined in the configuration file.

               MasterMachPriority
                        The machine priority for the parallel master
                        node.

               Max_Dstg_Starters
                        A machine-specific limit on the number of data
                        staging initiators. This is also the number of
                        initiators available on that machine for the
                        data_stage class.

               Max_Starters
                        Maximum number of initiators that can be used
                        simultaneously on this machine.

               Mcms     The MCMs information associated with this
                        machine has the format: 
                        mcm_info ... mcm_info
                         
                        The format of mcm_info is:
                         
                        MCMnumber Available Cpus: < cpulist > (Total Cpus)  
                        Used Cpus: < cpulist > (Total Cpus)  
                        Adapters: adapater_info .... adapter_info 
                        Total Tasks: (Tasks) 
                         
                        where:
                         
                        Available Cpus
                           Are the CPUs available for LoadLeveler on
                           this MCM.

                        Used Cpus
                           Are the CPUs used by LoadLeveler jobs from
                           this MCM.

                        Adapters Are the switch adapters connected to
                           this MCM.

                        Total tasks
                           Is the total number of tasks that are running
                           using CPUs of this MCM. 

                           where number is the MCM sequence number:
                            
                           cpulist  Is a blank-delimited list of
                           individual CPU IDs or CPU ranges, or a
                           combination of both CPU IDs and CPU ranges
                           associated with the MCM.

                           adapter_info

                           Has the format: 

                           [available windows, available memory]
                            
                           where:
                            
                           available windows
                           Is the total number of available windows.

                           available memory
                           Is the total available memory. It is the
                           number of rCxt blocks for switch adapters.

                           Tasks    Is the total number of tasks that
                           are running using the CPUs of this MCM.

               Memory   Regular physical memory, in megabytes, on this
                        machine.

               Name     Host name of the machine.

               OpSys    Operating system on this machine.

               PagesFreed
                        Pages freed per second. This value corresponds
                        to the "fr" value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesFreed field
                        has no meaning and should be ignored by the
                        user.

               PagesPaged In
                        Pages paged in from paging space per second.
                        This value corresponds to the "pi" value of the
                        vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedIn field
                        has no meaning and should be ignored by the
                        user.

               PagesPagedOut
                        Pages paged out to paging space per second. This
                        value corresponds to the "po" value of the
                        vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedOut
                        field has no meaning and should be ignored by
                        the user.

               PagesScanned
                        Pages scanned by the page-replacement algorithm
                        per second. This value corresponds to the "sr"
                        value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesScanned field
                        has no meaning and should be ignored by the
                        user.

               Pending  The number of job steps in this state on this
                        Schedd machine.

               Pool     The identifier of the pool where this startd
                        machine is located.

               Prestarted_Starters
                        The maximum number of Prestarted Starters that
                        can be started on this machine at any time.

               Remove Pending
                        The number of job steps in this state on this
                        Schedd machine.

               ReservationPermitted
                        Indicates whether or not the node can be
                        reserved. It is displayed as T or F (true or
                        false).

               Reservations
                        The IDs of reservations that will use the node
                        now or in the future.

               RSetSupportType
                        Indicates the type of RSet support set up on a
                        machine. Possible values are: 

                        RSET_MCM_AFFINITY
                           Creates and attaches RSets for tasks to
                           satisfy memory and affinity requests.
                        RSET_NONE
                           Indicates that LoadLeveler RSet support is
                           not available.
                        RSET_USER_DEFINED
                           Attaches user-created RSets to Tasks.

               Running Tasks
                        The number of initiators used by the startd
                        daemon to run LoadLeveler jobs. One initiator is
                        used for each serial job step. One initiator is
                        used for each task of a parallel job step.

               Running steps
                        The list of job steps currently running on this
                        machine.

               ScheddAvail
                        Flag indicating if machine is running a Schedd
                        daemon (0=no, 1=yes).

               ScheddRunning 
                        The number of job steps submitted to this
                        machine that are running somewhere in the
                        LoadLeveler cluster.

               ScheddState
                        The state of the Schedd daemon on this machine,
                        which can be one of the following: 
                        *  Down
                        *  Drned (Drained)
                        *  Drning (Draining)
                        *  Avail (Available)

               Speed    Speed associated with the machine.

               SMT      Indicates whether the simultaneous
                        multithreading (SMT) function is turned on, off,
                        or is not supported in the running machine.
                        Valid values are Enabled, Disabled, or Not
                        Supported.

               START    The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        jobs can be started on this machine.

               StartdAvail
                        Flag indicating if machine is running a startd
                        daemon (0=no, 1=yes).

               Starting The number of job steps in this state on this
                        Schedd machine.

               State    State of the startd daemon, which can be: 
                        *  Busy
                        *  Down
                        *  Drained
                        *  Draining
                        *  Flush
                        *  Idle
                        *  None
                        *  Running
                        *  Suspend
                         
                        For more information, see the description of the
                        startd daemon in TWS LoadLeveler: Using and
                        Administering.

               Subnet   The TCP/IP subnet that this machine resides on.

               SUSPEND  The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        running jobs should be suspended on this
                        machine.

               SYSPRIO  Actual expression that determines overall system
                        priority of a job step. Defined in the
                        configuration file.

               TimeStamp
                        The date and time the central manager last
                        received a status update from this Schedd
                        machine.

               Tmp      Available space, in kilobytes (less than 512 KB)
                        in the /tmp directory on this machine.

               Total Jobs
                        The number of total job steps submitted to this
                        Schedd machine.

               TotalMemory
                        The sum of configured regular and Large Page
                        memory.

               Unexpanded
                        The number of job steps in this state on this
                        Schedd machine.

               VACATE   The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        suspended jobs are vacated on this machine.

               Virtual Memory
                        Available swap space (free paging space) in
                        kilobytes, on this machine.

3. This example generates a listing of cluster information defined in
   the administration file and the Schedd version for cluster2. Only
   fields with data are displayed. 

   llstatus -X cluster2 -C
    
   The output representing a cluster is delineated with a cluster header
   and the Schedd version information from a remote cluster similar to
   the following:
    
   =================== Cluster cluster2 ================================
   llstatus: Sending request to Schedd "c188f2n08.ppd.pok.ibm.com" in 
             cluster "cluster2"
   
   cluster2: type = cluster
           Local = True
           inbound_schedd_port = 9605
           secure_schedd_port = 9607
           multicluster_security = NOT_SET
           ssl_cipher_list = ALL:eNULL:!aNULL
           inbound_hosts = c188f2n08.ppd.pok.ibm.com
           outbound_hosts = c188f2n08.ppd.pok.ibm.com
           exclude_classes = badtesters(cluster3) OKtesters(cluster1)
           main_scale_across_cluster = True
           allow_scale_across_jobs = True
   cluster1: type = cluster
           Local = False
           inbound_schedd_port = 9605
           secure_schedd_port = 9607
           multicluster_security = NOT_SET
           ssl_cipher_list = ALL:eNULL:!aNULL
           inbound_hosts = c188f2n02.ppd.pok.ibm.com
           outbound_hosts = c188f2n02.ppd.pok.ibm.com
           exclude_users = loadl(cluster2)
           exclude_groups = april(cluster3)
           include_classes = No_Class
           main_scale_across_cluster = False
           allow_scale_across_jobs = True
   cluster3: type = cluster
           Local = False
           inbound_schedd_port = 1966
           secure_schedd_port = 9607
           multicluster_security = NOT_SET
           ssl_cipher_list = ALL:eNULL:!aNULL
           inbound_hosts = c94n02.ppd.pok.ibm.com
           outbound_hosts = c94n02.ppd.pok.ibm.com(cluster1)
                            c94n06.ppd.pok.ibm.com(cluster2)
           main_scale_across_cluster = False
           allow_scale_across_jobs = True
   
           cluster2 schedd gateway Version:
           c188f2n08.ppd.pok.ibm.com   3.5.0.1  rsats001a  2009/01/23     
                RHEL  4.0  132

4. This example generates a listing of all of the consumable resources
   associated with all of the machines in the LoadLeveler cluster. 

   llstatus -R    

   You should receive output similar to the following:
   
   Machine                       Consumable Resource(Available, Total)
   -------------------------     -------------------------------------
   c209f1n01.ppd.pok.ibm.com     ConsumableCpus(4,4)+ ConsumableMemory 
                                  (1.000 gb,1.000 gb) n01_res(123,500)
   c209f1n02.ppd.pok.ibm.com     ConsumableCpus< 0 1 2 3 4>< 0 1 2 3 4 >  
                                  n02_res(123,500) Frame5(10,10)
   c209f1n05.ppd.pok.ibm.com     ConsumableCpus(4,4)+ ConsumableMemory 
                                  (1.000 gb,1.000 gb) spice2g6(250,360)
   
   Resources with "+" appended to their names have the Total value 
   reported from Startd.
    
   Note:  The individual CPU ID < > notation will be used to list
          individual CPU IDs instead of the CPU count ( ) notation for
          machines where the RSET_SUPPORT configuration file keyword is
          set to RSET_MCM_AFFINITY. The CPU count ( ) notation will be
          used when the RSET_SUPPORT configuration file keyword is set 
	  to RSET_USER_DEFINED or RSET_NONE, or if this keyword is not
          specified in the configuration file.

5. This example generates a listing of information related to MCMs of
   machines in the LoadLeveler cluster. 
      
   llstatus -M
    
   You should receive output similar to the following:
    
   Machine               MCM details 
   --------------------- ------------------------------------------------
   c890f1ec12.ppd.pok.ibm.com
         MCM0
            Available Cpus :< 0-15 >(16)
            Used Cpus      :< >(0)
            Adapters       :network18338657682652659713[64,0 rCxt Blks] \
                              DOWN
                            network18338657682652659714[64,0 rCxt Blks]
            Total Tasks    :(0)
         MCM1
            Available Cpus :< 16-31 >(16)
            Used Cpus      :< >(0)
            Adapters       :network18338657682652659715[64,0 rCxt Blks]
                            network18338657682652659716[64,0 rCxt Blks]
            Total Tasks    :(0)
         MCM2
            Available Cpus :< 32-47 >(16)
            Used Cpus      :< >(0)
            Adapters       :network18338657682652659713[64,0 rCxt Blks]
                            network18338657682652659714[64,0 rCxt Blks]
            Total Tasks    :(0)
         MCM3
            Available Cpus :< 48-63 >(16)
            Used Cpus      :< >(0)
            Adapters       :network18338657682652659715[64,0 rCxt Blks]
                            network18338657682652659716[64,0 rCxt Blks]
            Total Tasks    :(0)                         
    
   Note: The -M option will list the MCM information only when the
         RSET_SUPPORT configuration file keyword is set to
         RSET_MCM_AFFINITY.

6. This example generates a listing of all of the floating consumable
   resources associated with all of the machines in the LoadLeveler
   cluster. This option should not be specified with any other option. 

   llstatus -F
    
   You should receive output similar to the following:
    
   Floating Resource              Available     Total          
   ------------------------------ ------------- ---------------
   EDA_licenses                   20            29           
   Frame5                         15            20           
   WorkBench6                     5             7            
   XYZ_software                   6             6            

7. This example generates a customized and formatted standard listing.    
 
   llstatus -f %n %scs %inq %m %v %sts %l %o
    
   You should receive output similar to the following:    

   Name             Schedd  InQ  Memory  FreeVMemory Startd LdAvg  OpSys
   ll5.pok.ibm.com  Avail   0    128     22708       Run    0.23   AIX53
   ll6.pok.ibm.com  Avail   3    224     16732       Run    0.51   AIX53
   
   R6000/AIX53             2 machines      3  jobs      3  running tasks
   Total Machines          2 machines      3  jobs      3  running tasks
   
   The Central Manager is defined on ll5.pok.ibm.com
   
   The BACKFILL scheduler is in use
   
   All machines on the machine_list are present.

8. This example generates a customized and unformatted (raw) standard
   listing. 

   Customized, Unformatted Standard Listing: A customized Output fields
   are separated by an exclamation point (!).
    
   llstatus -r %n %scs %inq %m %v %sts %l %o
    
   You should receive output similar to the following:
    
   ll5.pok.ibm.com!Avail!0!128!22688!Running!0.14!AIX53
   ll6.pok.ibm.com!Avail!3!224!16668!Running!0.37!AIX53

9. This example generates a listing containing information about the
   status of adapters associated with all of the machines in the
   LoadLeveler cluster: 

   llstatus -a
    
   You should receive output similar to the following:
    
   =====================================================================
   c395f3n07.ppd.pok.ibm.com
   iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
   network1833865768265265971s(striped,ml0,192.168.200.22,,-1,64/64,
      0 rCxt Blks,11,READY)
   network18338657682652659713(aggregate,,,192.168.200.22,-1,64/64,
      0 rCxt Blks,1,READY)
   ib0(InfiniBand,c395f3n07ib0,192.168.100.22,192.168.200.22,158473815,
      64,0 rCxt Blks,1,READY,1,MCM1)
   network18338657682652659714(aggregate,,,192.168.200.22,-1,64/64,
      0 rCxt Blks,1,READY)
   ib1(InfiniBand,c395f3n07ib1,192.168.101.22,192.168.200.22,158473815,
      64,0 rCxt Blks,1,READY,2,MCM1)
   en0(ethernet,c395f3n07.ppd.pok.ibm.com,9.114.30.87,,READY)
   ml0(multilink,c395f3n07ml0,192.168.200.22,,READY)
    
   *  For a switch adapter, the information format is: 

      adapter_name(network_type, interface_name, interface_address, 
      multilink_address, switch_node_number or adapter_logical_id, 
      available_adapter_windows/ total_adapter_windows, 
      total rCxt blocks, adapter_fabric_connectivity, adapter_state) 
       
      For example:
       
      iba0(InfiniBand,,,,-1,0/0,0/0 rCxt Blks,1,READY)
      network1833865768265265971s(striped,,,,-1,128/128,0rCxt Blks,1, \
         READY)
      network18338657682652659716(aggregate,,,,-1,128/128,0rCxt Blks,1, \
         READY) 
       
      Note that InfiniBand adapters contain additional information. The
      format is:
       
      adapter_name(network_type, interface_name, interface_address, 
      multilink_address, switch_node_number or adapter_logical_id, 
      total_adapter_windows, total rCxt blocks, 
      adapter_fabric_connectivity, adapter_state, port_number, MCM_id) 
       
      For example:
       
      ib0(InfiniBand,192.168.197.9,192.168.197.9,,158516969,128,
      0rCxt Blks,1,READY,1,MCM-1)

   *  For non-switch adapters, the format is: 
      adapter_name(network_type, interface_name, interface_address, 
      multilink_address, adapter_state)       

      For example:
     
      en0(ethernet,c197blade8b09.ppd.pok.ibm.com,9.114.198.233,,READY)

   *  For InfiniBand, this example displays the port number on each
      InfiniBand adapter. The llstatus command does not show port
      information for adapters that are not InfiniBand adapters: 

      llstatus -a
       
      You should receive output similar to the following:
       
      ==================================================================
      c890f1ec12.ppd.pok.ibm.com
      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      iba1(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      iba2(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      iba3(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      network1833865768265265971s(striped,,,,-1,128/128,0 rCxt Blks,
         1111,READY)
      network18338657682652659713(aggregate,,,,-1,128/128,0 rCxt Blks,1,
         READY)
      ib4(InfiniBand,192.168.12.12,192.168.12.12,,158486540,64,
         0 rCxt Blks,1,READY,1,MCM2)
      ib0(InfiniBand,192.168.8.12,192.168.8.12,,158486540,64,
         0 rCxt Blks,1,READY,1,MCM0)
      network18338657682652659714(aggregate,,,,-1,128/128,0 rCxt Blks,1,
         READY)
      ib5(InfiniBand,192.168.13.12,192.168.13.12,,158486540,64,
         0 rCxt Blks,1,READY,2,MCM2)
      ib1(InfiniBand,192.168.9.12,192.168.9.12,,158486540,64,
         0 rCxt Blks,1,READY,2,MCM0)
      network18338657682652659715(aggregate,,,,-1,128/128,0 rCxt Blks,1,
         READY)
      ib6(InfiniBand,192.168.14.12,192.168.14.12,,158486540,64,
         0 rCxt Blks,1,READY,1,MCM3)
      ib2(InfiniBand,192.168.10.12,192.168.10.12,,158486540,64,
         0 rCxt Blks,1,READY,1,MCM1)
      network18338657682652659716(aggregate,,,,-1,128/128,0 rCxt Blks,1,
         READY)
      ib7(InfiniBand,192.168.15.12,192.168.15.12,,158486540,64,
         0 rCxt Blks,1,READY,2,MCM3)
      ib3(InfiniBand,192.168.11.12,192.168.11.12,,158486540,64,
         0 rCxt Blks,1,READY,2,MCM1)
      en0(ethernet,c890f1ec12.ppd.pok.ibm.com,9.114.80.12,,READY)
      
      ==================================================================
      c890f1ec09.ppd.pok.ibm.com
      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      iba1(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      iba2(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      iba3(InfiniBand,,,,-1,0,0 rCxt Blks,11,READY)
      network1833865768265265971s(striped,,,,-1,128/128,0 rCxt Blks,
         1111,READY)
      network18338657682652659713(aggregate,,,,-1,128/128,0 rCxt Blks,1,
         READY)
      ib4(InfiniBand,192.168.12.9,192.168.12.9,,158486537,64,
         0 rCxt Blks,1,READY,1,MCM2)
      ib0(InfiniBand,192.168.8.9,192.168.8.9,,158486537,64,
         0 rCxt Blks,1,READY,1,MCM0)
      network18338657682652659714(aggregate,,,,-1,128/128,
         0 rCxt Blks,1,READY)
      ib5(InfiniBand,192.168.13.9,192.168.13.9,,158486537,64,
         0 rCxt Blks,1,READY,2,MCM2)
      ib1(InfiniBand,192.168.9.9,192.168.9.9,,158486537,64,
         0 rCxt Blks,1,READY,2,MCM0)
      network18338657682652659715(aggregate,,,,-1,128/128,0 rCxt Blks,1,
         READY)
      ib6(InfiniBand,192.168.14.9,192.168.14.9,,158486537,64,
         0 rCxt Blks,1,READY,1,MCM3)
      ib2(InfiniBand,192.168.10.9,192.168.10.9,,158486537,64,
         0 rCxt Blks,1,READY,1,MCM1)
      network18338657682652659716(aggregate,,,,-1,128/128,
         0 rCxt Blks,1,READY)
      ib7(InfiniBand,192.168.15.9,192.168.15.9,,158486537,64,
         0 rCxt Blks,1,READY,2,MCM3)
      ib3(InfiniBand,192.168.11.9,192.168.11.9,,158486537,64,
         0 rCxt Blks,1,READY,2,MCM1)
      en0(ethernet,c890f1ec09.ppd.pok.ibm.com,9.114.80.9,,READY)

10. This example generates a listing containing information about the
    status of the Blue Gene/L system in the LoadLeveler cluster. 

    llstatus -b
  
    You should receive output similar to the following:
    
    Name          Base Partitions  c-nodes    InQ    Run
    BGL           1x2x4            8x16x32    4      1

11. This example generates information for base Blue Gene/L partition
    R010: 

    llstatus -B R010
    
    You should receive output similar to the following:
    
    Base Partition Id: R010
      Base Partition State: UP
      Location: (0,1,0)
      C-node Memory: 1024 mb
      Number of IONodes: 64
      Sub Divided Busy: False
      PartitionState=READY Partition=GPFS_R010

12. This example generates information for Blue Gene/L partition
    GPFS_R010:
    
    llstatus -P GPFS_R010
    
    You should receive output similar to the following:
    
    Partition Id: GPFS_R010
      Partition State: READY
      Description: Generated via BlockBuilder
      Owner: apeters
      Users: 
      Connection: TORUS
      Size: 512
      Shape: 1x1x1
      Number of IONodes: 64
      Mode: VIRTUAL_NODE
      MloaderImage: /bgl/BlueLight/ppcfloor/bglsys/bin/mmcs-mloader.rts
      BlrtsImage: /bgl/BlueLight/ppcfloor/bglsys/bin/rts_hw.rts
      LinuxImage: /bgl/BlueLight/ppcfloor/bglsys/bin/zImage.elf
      RamDiskImage: /bgl/BlueLight/ppcfloor/bglsys/bin/ramdisk.elf
      Small Partitions: False
      Base Partition List: R010 
      Switch ID: X_R010
        Switch State: UP
        Base Partition: R010
        Switch Dimension: X
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY 
	  Partition=GPFS_R010
      Switch ID: Y_R010
        Switch State: UP
        Base Partition: R010
        Switch Dimension: Y
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY 
	  Partition=GPFS_R010
      Switch ID: Z_R010
        Switch State: UP
        Base Partition: R010
        Switch Dimension: Z
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY 
	  Partition=GPFS_R010

13. The following example shows output for the llstatus -l command that
    displays the SMT state for the machine: 

    ====================================================================
         Name = devf1n01.clusters.com
      Machine = devf1n01.clusters.com
         Arch = ppc64
        OpSys = Linux2
    .
    .
    .
      Feature = SMT
    .
    .
    .
          SMT = Enabled | Disabled | Not Supported
    TimeStamp = Fri 23 Jan 2009 04:44:06 PM CST
    .
    .
    .  

14. This example generates a listing containing information about the
    status of the Blue Gene/P system in the LoadLeveler cluster. 

    llstatus -b
    
    You should receive output similar to the following:
    
    Name          Base Partitions  c-nodes    InQ    Run
    BGP           4x1x2            32x8x16    0      0

15. This example generates information for base Blue Gene/P partition
    R001:
    
    llstatus -B R001
    
    You should receive output similar to the following:
    
    Base Partition Id: R00-M0
      Base Partition State: UP
      Location: (0,0,0)
      C-node Memory: 2048 mb
      Number of IONodes: 32
      Sub Divided Busy: True
      Node Card List:
        NodeCardId=N00      NodeCardState=UP    Quarter=Q1 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N01      NodeCardState=UP    Quarter=Q1 
	   PartitionState=READY Partition=R00-M0-N01
        NodeCardId=N02      NodeCardState=UP    Quarter=Q1 
	   SubDividedBusy=True 
          IONodeId=J00      IPAddress=172.16.103.5    
	     PartitionState=READY Partition=R00-M0-N02-J00 
          IONodeId=J01      IPAddress=172.16.103.6    
	     PartitionState=READY Partition=R00-M0-N02-J01 
        NodeCardId=N03      NodeCardState=UP    Quarter=Q1 
	   SubDividedBusy=True 
          IONodeId=J00      IPAddress=172.16.103.7    
	     PartitionState=NONE Partition=NONE 
          IONodeId=J01      IPAddress=172.16.103.8    
	     PartitionState=READY Partition=R00-M0-N03-J01
        NodeCardId=N04      NodeCardState=UP    Quarter=Q2 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.9    
	     PartitionState=READY Partition=R00-M0-N04-J00
          IONodeId=J01      IPAddress=172.16.103.10   
	     PartitionState=NONE Partition=NONE
        NodeCardId=N05      NodeCardState=UP    Quarter=Q2 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N06      NodeCardState=UP    Quarter=Q2 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.13   
	     PartitionState=READY Partition=R00-M0-N06-J00
          IONodeId=J01      IPAddress=172.16.103.14   
	     PartitionState=NONE Partition=NONE
        NodeCardId=N07      NodeCardState=UP    Quarter=Q2 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N08      NodeCardState=UP    Quarter=Q3 
	   PartitionState=READY Partition=R00-M0-N08-32
        NodeCardId=N09      NodeCardState=UP    Quarter=Q3 
	   PartitionState=READY Partition=R00-M0-N09
        NodeCardId=N10      NodeCardState=UP    Quarter=Q3 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.21   
	     PartitionState=READY Partition=R00-M0-N10-J00
          IONodeId=J01      IPAddress=172.16.103.22   
	     PartitionState=READY Partition=R00-M0-N10-J01
        NodeCardId=N11      NodeCardState=UP    Quarter=Q3 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N12      NodeCardState=UP    Quarter=Q4 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.25   
	     PartitionState=READY Partition=R00-M0-N12-J00
          IONodeId=J01      IPAddress=172.16.103.26   
	     PartitionState=READY Partition=R00-M0-N12-J01
        NodeCardId=N13      NodeCardState=UP    Quarter=Q4 
	   PartitionState=READY Partition=R00-M0-N13
        NodeCardId=N14      NodeCardState=UP    Quarter=Q4 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N15      NodeCardState=UP    Quarter=Q4 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.31   
	     PartitionState=READY Partition=R00-M0-N15-J00
          IONodeId=J01      IPAddress=172.16.103.32   
	     PartitionState=NONE Partition=NONE

16. This example generates information for Blue Gene/P partition
    R00-M0-N08-32:
    
    llstatus -P R00-M0-N08-32
    
    You should receive output similar to the following:
    
    Partition Id: R00-M0-N08-32
      Partition State: READY
      Description: Generated via BlockBuilder
      Owner: mmundy
      Users: 
      Connection: MESH
      Size: 32
      Shape: 0x0x0
      Number of IONodes: 2
      IONodes / Base Partition: N08-J00 N08-J01 
      MloaderImage: /bgsys/drivers/ppcfloor/boot/uloader
      CnLoadImage: /bgsys/drivers/ppcfloor/boot/cns,/bgsys/drivers
         /ppcfloor/boot/cnk
      IoLoadImage: /bgsys/drivers/ppcfloor/boot/cns, 
        /bgsys/drivers/ppcfloor/boot/linux,/bgsys/drivers/ppcfloor/boot
	/ramdisk
      Small Partitions: True
      Base Partition List: R00-M0 
      Node Card List: N08 

17. This example displays information pertaining to data staging: 

    llstatus -l c197blade1b05
    
    You should receive output similar to the following:
     
    ==============================================================
    Name                = c197blade1b05.ppd.pok.ibm.com
    Machine             = c197blade1b05.ppd.pok.ibm.com
    Arch                = i386
    OpSys               = Linux2
    SYSPRIO             = (0 - QDate)
    MACHPRIO            = (0 - LoadAvg)
    .
    .
    .
    LoadAvg             = 0.000000
    ConfiguredClasses   = small(2) medium(2) large(2) data_stage(3)
    AvailableClasses    = small(2) medium(2) large(2) data_stage(1)
    DrainingClasses     =
    DrainedClasses      =
    Pool                =
    FabricConnectivity  =
    Adapter             = eth0(unknown,c197blade1b05.ppd.pok.ibm.com,
                          9.114.198.5,)
    Feature             =
    Max_Starters        = 1
    Max_Dstg_Starters   = 3
    Prestarted_Starters = 1
    Total Memory        = 502 mb
    Memory              = 502 mb

18. On a system that has one InfiniBand adapter and multiple MCMs, the
    llstatus -a or llstatus -M command displays the InfiniBand network
    interfaces connected to only one MCM. Processors in the other MCMs,
    however, can still communicate through the same network interfaces. 

    *  For example, if you issue: 

       llstatus -a c395f2n02
       
       You should receive output similar to the following:
       
       =================================================================
       c395f2n02.ppd.pok.ibm.com
       iba0(InfiniBand,,,192.168.200.10,-1,0,0 rCxt Blks,11,READY)
       network1833865768265265971s(striped,ml0,192.168.200.10,,-1,60/64,
          0 rCxt Blks,11,READY)
       network18338657682652659713(aggregate,,,192.168.200.10,-1,60/64,
          0 rCxt Blks,1,READY)
       ib0(InfiniBand,c395f2n02ib0,192.168.100.10,192.168.200.10,
          158473802,64,0 rCxt Blks,1,READY,1,MCM1)
       network18338657682652659714(aggregate,,,192.168.200.10,-1,60/64,
          0 rCxt Blks,1,READY)
       ib1(InfiniBand,c395f2n02ib1,192.168.101.10,192.168.200.10,
          158473802,64,0 rCxt Blks,1,READY,2,MCM1)
       en0(ethernet,c395f2n02.ppd.pok.ibm.com,9.114.30.74,,READY)
       ml0(multilink,c395f2n02ml0,192.168.200.10,,READY)

    *  For example, if you issue: 

       llstatus -M c395f2n02
       
       You should receive output similar to the following:
       
       Machine               MCM details
       --------------------- -------------------------------------------
       c395f2n02.ppd.pok.ibm.com
             MCM0
                Available Cpus :< 0-3 >(4)
                Used Cpus      :< 0-3 >(4)
                Adapters       :
                Total Tasks    :(4)
             MCM1
                Available Cpus :< 4-7 >(4)
                Used Cpus      :< >(0)
                Adapters       :network18338657682652659713[64,
		                0 rCxt Blks]
                                network18338657682652659714[64,
				0 rCxt Blks]
                Total Tasks    :(0)
             MCM2
                Available Cpus :< 8-11 >(4)
                Used Cpus      :< >(0)
                Adapters       :
                Total Tasks    :(0)
             MCM3
                Available Cpus :< 12-15 >(4)
                Used Cpus      :< >(0)
                Adapters       :
                Total Tasks    :(0)

Security

LoadLeveler administrators and users can issue this command.
